@@ -5,6 +5,14 @@ class AuthenticationException(BaseException):
     """Raise this when there is an authentication issue."""
 
 
+class BadMessageException(BaseException):
+    """Raise this when a bad message is sent."""
+
+
+class BadRequestException(BaseException):
+    """Raise this when a bad request is sent."""
+
+
 class ConnectionClosedException(BaseException):
     """Raise this when connection is closed."""
 
@@ -13,5 +21,5 @@ class ConnectionErrorException(BaseException):
     """Raise this when error connecting."""
 
 
-class BadMessageException(BaseException):
-    """Raise this when a bad message is sent."""
+class DataMissingException(BaseException):
+    """Raise this when data is missing."""
